# @agnostack/authorizenet-request

[![npm version](https://img.shields.io/npm/v/@agnostack/authorizenet-request.svg)](https://www.npmjs.com/package/@agnostack/authorizenet-request) [![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release) [![code style: prettier](https://img.shields.io/badge/code_style-prettier-ff69b4.svg)](https://github.com/prettier/prettier) [![CircleCI](https://img.shields.io/circleci/project/github/agnostack/authorizenet-request.svg?label=circleci)](https://circleci.com/gh/agnostack/authorizenet-request)

> 🎮 Minimal [Authorize.Net](https://www.authorize.net/) API request library for Node

## Installation

```bash
yarn add @agnostack/authorizenet-request # npm install @agnostack/authorizenet-request
```

## Quickstart

```js
const { createClient } = require('@agnostack/authorizenet-request');
// import { createClient } from '@agnostack/authorizenet-request'

// NOTE: uses 'api.authorize.net' endpoint by default
const authorizenet = new createClient({
  api_login_id: '...', // Authorize.Net Login ID
  secret_key: '...' // Authorize.Net Transaction Key
});

authorizenet
  .post({
    requestId: 'getCustomerProfileRequest',
    requestData: {
      email: 'customer-profile-email@here.com'
    }
  })
  .then(console.log)
  .catch(console.error);

authorizenet
  .post({
    requestId: 'getCustomerProfileRequest',
    requestData: {
      customerProfileId: '1234567',
      includeIssuerInfo: true
    }
  })
  .then(console.log)
  .catch(console.error);

authorizenet
  .post({
    requestId: 'createTransactionRequest',
    requestData: {
      transactionRequest: {
        transactionType: 'refundTransaction',
        amount: '5',
        payment: {
          creditCard: {
            cardNumber: '5424000000000015',
            expirationDate: '2020-12'
          }
        },
        refTransId: '123456'
      }
    }
  })
  .then(console.log)
  .catch(console.error);

authorizenet
  .post({
    requestId: 'getTransactionDetailsRequest',
    requestData: {
      transId: '1234567890'
    }
  })
  .then(console.log)
  .catch(console.error);
```

## Kitchen sink

```js
const authorizenet = new createClient({
  api_domain: 'api.authorize.net', // OR 'apitest.authorize.net'
  api_login_id: '...',
  secret_key: '...',
  application: '...',
  headers: {
    // ...
  }
});
```

## Custom headers per request

The API provides you the ability to send various request headers that change the way data is stored or retrieved.

By default this library will encode all data as JSON, however you can customise this by setting your own `Content-Type` header as an additional argument to `post`.

**Note**: If you add the `Content-Type` custom header to `post` you will need to encode `data` yourself.

```js
const authorizenet = new createClient({
  api_login_id: '...',
  secret_key: '...'
});

const headers = {
  'X-My-Header': 'custom'
};

authorizenet
  .post(
    {
      requestId: 'getCustomerProfileRequest',
      requestData: {
        email: 'customer-profile-email@here.com'
      }
    },
    headers
  )
  .then(console.log)
  .catch(console.error);
```

_Contact [Adam Grohs](https://www.linkedin.com/in/adamgrohs/) @ [agnoStack.](https://agnostack.com/) for any questions._
